(()=>{"use strict";var e={d:(t,n)=>{for(var i in n)e.o(n,i)&&!e.o(t,i)&&Object.defineProperty(t,i,{enumerable:!0,get:n[i]})}};e.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),e.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),e.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})};var t={};e.r(t),e.d(t,{FontSizeV3Configuration:()=>S});const n=("undefined"!=typeof window?window:e.g).MathJax._.components.global,i=(n.GLOBAL,n.isObject,n.combineConfig,n.combineDefaults,n.combineWithMathJax),a=(n.MathJax,MathJax._.input.tex.HandlerTypes),o=a.ConfigurationType,r=a.HandlerType,s=MathJax._.input.tex.TokenMap,p=(s.parseResult,s.AbstractTokenMap,s.RegExpMap,s.AbstractParseMap,s.CharacterMap,s.DelimiterMap,s.MacroMap,s.CommandMap),l=(s.EnvironmentMap,MathJax._.input.tex.Configuration),u=l.Configuration,c=(l.ConfigurationHandler,l.ParserConfiguration,MathJax._.input.tex.base.BaseMethods),f=(c.splitAlignArray,c.default);new p("fontsizev3-macros",{tiny:[f.SetSize,.5],Tiny:[f.SetSize,.6],scriptsize:[f.SetSize,.7],small:[f.SetSize,.85],normalsize:[f.SetSize,1],large:[f.SetSize,1.2],Large:[f.SetSize,1.44],LARGE:[f.SetSize,1.73],huge:[f.SetSize,2.07],Huge:[f.SetSize,2.49]});const S=u.create("fontsizev3",{[o.HANDLER]:{[r.MACRO]:["fontsizev3-macros"]}});MathJax.loader&&MathJax.loader.checkVersion("[tex]/fontsizev3","4.1.3","tex-extension"),i({_:{input:{tex:{fontsizev3:{FontSizeV3Configuration:t}}}}})})();