(()=>{"use strict";var e={};e.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}();const o="4.1.3",t={},r="undefined"!=typeof window?window:void 0!==e.g?e.g:"undefined"!=typeof globalThis?globalThis:t;void 0!==r.MathJax&&r.MathJax.constructor==={}.constructor||(r.MathJax={}),r.MathJax.version||(r.MathJax={version:o,_:{},config:r.MathJax});const n=r.MathJax;var a,i,c,s,l=function(e,o,t,r){return new(t||(t=Promise))(function(n,a){function i(e){try{s(r.next(e))}catch(e){a(e)}}function c(e){try{s(r.throw(e))}catch(e){a(e)}}function s(e){var o;e.done?n(e.value):(o=e.value,o instanceof t?o:new t(function(e){e(o)})).then(i,c)}s((r=r.apply(e,o||[])).next())})};[[null===(a=n._.ui)||void 0===a?void 0:a.dialog,"core",()=>{const{DraggableDialog:e}=n._.ui.dialog.DraggableDialog;delete e.styles["@media (prefers-color-scheme: dark)"]}],[null===(i=n._.a11y)||void 0===i?void 0:i.explorer,"a11y/explorer",()=>{const e=n._.a11y.explorer.Region;for(const o of["LiveRegion","HoverRegion","ToolTip"])e[o].style.styles["@media (prefers-color-scheme: dark)"]={};e.LiveRegion.style.styles["@media (prefers-color-scheme: dark)"]["mjx-ignore"]={ignore:1},n.startup.extendHandler(e=>(delete e.documentClass.speechStyles["@media (prefers-color-scheme: dark) /* explorer */"],e))}],[null===(c=n._.output)||void 0===c?void 0:c.chtml,"output/chtml",()=>{const{CHTML:e}=n._.output.chtml_ts;delete e.commonStyles["@media (prefers-color-scheme: dark)"];const{ChtmlMaction:o}=n._.output.chtml.Wrappers.maction;delete o.styles["@media (prefers-color-scheme: dark) /* chtml maction */"]}],[null===(s=n._.output)||void 0===s?void 0:s.svg,"output/svg",()=>{const{SVG:e}=n._.output.svg_ts;delete e.commonStyles["@media (prefers-color-scheme: dark)"];const{SvgMaction:o}=n._.output.svg.Wrappers.maction;delete o.styles["@media (prefers-color-scheme: dark) /* svg maction */"]}]].forEach(([e,o,t])=>{var r;if(e)t();else{const e=n.config.loader;null!==(r=e[o])&&void 0!==r||(e[o]={});const a=e[o].checkReady;e[o].checkReady=()=>l(void 0,void 0,void 0,function*(){return a&&(yield a()),t()})}}),MathJax.loader&&MathJax.loader.checkVersion("ui/no-dark-mode",o,"extension")})();